import "date-fns";
import React from "react";
import {
  Button,
  Fab,
  Grid,
  TextField,
  FormControl,
  FormControlLabel,
  Select,
  MenuItem,
  Paper,
  Typography,
  Divider,
  Switch,
  Table,
  TableCell,
  TableHead,
  TableRow,
  TableBody,
  IconButton,
  Input,
  InputLabel,
  InputAdornment
} from "@material-ui/core";
import Slider from "@material-ui/lab/Slider";
import TrashIcon from "@material-ui/icons/Delete";
import AddIcon from "@material-ui/icons/Add";
import SaveAltIcon from "@material-ui/icons/SaveAlt";
import MoreHorizonIcon from "@material-ui/icons/MoreHoriz";
import MoreHoriz from "@material-ui/icons/MoreHoriz";
import ChevronLeftIcon from "@material-ui/icons/ChevronLeft";
import { makeStyles } from "@material-ui/core/styles";
import DateFnsUtils from "@date-io/date-fns";
import {
  MuiPickersUtilsProvider,
  KeyboardTimePicker,
  KeyboardDatePicker
} from "@material-ui/pickers";

const useStyles = makeStyles({
  grid: {
    width: "60%"
  },
  paper: {
    margin: 12,
    paddingBottom: 12
  },
  paperHeaderBack: {
    color: "grey",
    padding: 12
  },
  paperHeader: {
    color: "grey",
    padding: "12px"
  },
  paperHeaderActions: {},
  paperActions: {
    justify: "flex-end",
    padding: 0,
    margin: 0
  },
  paperActionItem: {
    paddingLeft: 40
  },
  item: {
    padding: "12px",
    paddingRight: "12px"
  },
  amount: {
    textAlign: "right"
  },
  formInput: {
    margin: 6
  },
  formContainer: {
    display: "flex"
  },
  innerContainer: {
    spacing: 12
  },
  innerLeftItem: {
    paddingLeft: 0,
    paddingRight: 12
  },
  innerRightItem: {
    paddingLeft: 12,
    paddingRight: 0
  },
  selectItem: {
    width: "100%"
  },
  textField: {
    width: "100%"
  },
  fab: {
    position: "absolute",
    bottom: 20,
    right: 20
  },
  readOnly: {
    color: "grey"
  }
});

const marks = [
  {
    value: 0,
    label: "very bad"
  },
  {
    value: 1,
    label: "bad"
  },
  {
    value: 2,
    label: "no so bad"
  },
  {
    value: 3,
    label: "rather good"
  },
  {
    value: 4,
    label: "good"
  },
  {
    value: 5,
    label: "very good"
  }
];

function valuetext(value) {
  return `${value}°C`;
}

function valueLabelFormat(value) {
  return marks.findIndex(mark => mark.value === value) + 1;
}

function createData(a, b, c, d, e, f, g, h, i, j, k) {
  return { a, b, c, d, e, f, g, h, i, j, k };
}

const rowsServices = [
  createData("A1  General Consultation", "1.00", "400.00"),
  createData("I113  BLOOD SUGAR-RANDOM OR FASTING", "1.00", "1250.00")
];

const rowsItems = [
  createData("0182  PARACETAMOL TABS 500 MG", "2.00", "10.00")
];

export default function MaterialUIPickers() {
  const classes = useStyles();

  return (
    <MuiPickersUtilsProvider utils={DateFnsUtils}>
      <form className={classes.formContainer} noValidate autoComplete="off">
        <Grid container>
          <Grid item xs={12}>
            <Paper className={classes.paper}>
              <Grid container>
                <Grid item xs={1} className={classes.paperHeaderBack}>
                  <IconButton>
                    <ChevronLeftIcon />
                  </IconButton>
                </Grid>
                <Grid container xs={11} alignItems="center">
                  <Grid item xs={12} className={classes.paperHeader}>
                    <Typography variant="h6">Claim Details</Typography>
                  </Grid>
                </Grid>
                <Grid item xs={12}>
                  <Divider />
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <TextField
                    id="standard-name"
                    label="Health Facility"
                    className={classes.textField}
                    value="VIHC001 - Juilöa Health Centre"
                    margin="normal"
                    readOnly={true}
                    InputProps={{
                      className: classes.readOnly
                    }}
                  />
                </Grid>
                <Grid item xs={3} className={classes.item} />
                <Grid item xs={3} className={classes.item}>
                  <KeyboardDatePicker
                    margin="normal"
                    id="mui-pickers-date"
                    label="Visit Date From"
                    fullWidth={true}
                    KeyboardButtonProps={{
                      "aria-label": "change date"
                    }}
                    readOnly={true}
                    InputProps={{
                      className: classes.readOnly
                    }}
                  />
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <KeyboardDatePicker
                    margin="normal"
                    id="mui-pickers-date"
                    label="Visit Date To"
                    fullWidth={true}
                    KeyboardButtonProps={{
                      "aria-label": "change date"
                    }}
                    readOnly={true}
                    InputProps={{
                      className: classes.readOnly
                    }}
                  />
                </Grid>

                <Grid item xs={3} className={classes.item}>
                  <TextField
                    id="standard-name"
                    label="Patient"
                    className={classes.textField}
                    value="Doni Ilina"
                    margin="normal"
                    readOnly={true}
                    InputProps={{
                      className: classes.readOnly
                    }}
                  />
                </Grid>

                <Grid item xs={3} className={classes.item}>
                  <TextField
                    id="standard-name"
                    label="Insurance"
                    className={classes.textField}
                    value="105000002"
                    margin="normal"
                    readOnly={true}
                    InputProps={{
                      className: classes.readOnly
                    }}
                  />
                </Grid>
                <Grid item xs={3} className={classes.item}>
                  <TextField
                    id="standard-name"
                    label="Guarantee"
                    className={classes.textField}
                    value=""
                    margin="normal"
                    readOnly={true}
                    InputProps={{
                      className: classes.readOnly
                    }}
                  />
                </Grid>
                <Grid item xs={3} className={classes.item} />

                <Grid item xs={6} className={classes.item}>
                  <Grid container className={classes.innerContainer}>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <TextField
                        id="standard-name"
                        label="Main Dg."
                        className={classes.textField}
                        value="A000 Cholera due to Vibrio cholerae 01, biovar cholerae"
                        margin="normal"
                        readOnly={true}
                        InputProps={{
                          className: classes.readOnly
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="visit-type-name"
                        label="Visit Type"
                        className={classes.textField}
                        value="Emergency"
                        margin="normal"
                        readOnly={true}
                        InputProps={{
                          className: classes.readOnly
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <TextField
                        id="standard-name"
                        label="Sec Dg1"
                        className={classes.textField}
                        value="A001 Cholera due to Vibrio cholerae 01, biovar eltor"
                        margin="normal"
                        readOnly={true}
                        InputProps={{
                          className: classes.readOnly
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="standard-name"
                        label="Sec Dg2"
                        className={classes.textField}
                        value=""
                        margin="normal"
                        readOnly={true}
                        InputProps={{
                          className: classes.readOnly
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <TextField
                        id="standard-name"
                        label="Sec Dg3"
                        className={classes.textField}
                        value=""
                        margin="normal"
                        readOnly={true}
                        InputProps={{
                          className: classes.readOnly
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="standard-name"
                        label="Sec Dg4"
                        className={classes.textField}
                        value=""
                        margin="normal"
                        readOnly={true}
                        InputProps={{
                          className: classes.readOnly
                        }}
                      />
                    </Grid>
                  </Grid>
                </Grid>
                <Grid item xs={6} className={classes.item}>
                  <Grid container className={classes.innerContainer}>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <TextField
                        id="standard-name"
                        label="Claim No."
                        className={classes.textField}
                        value="CIB00001"
                        margin="normal"
                        readOnly={true}
                        InputProps={{
                          className: classes.readOnly
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="standard-name"
                        label="Claimed"
                        className={classes.textField}
                        value="5250"
                        margin="normal"
                        inputProps={{
                          className: classes.amount
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <KeyboardDatePicker
                        margin="normal"
                        id="mui-pickers-date"
                        label="Date Claimed"
                        fullWidth={true}
                        KeyboardButtonProps={{
                          "aria-label": "change date"
                        }}
                        readOnly={true}
                        InputProps={{
                          className: classes.readOnly
                        }}
                        color="grey"
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="standard-name"
                        label="Adjusted"
                        className={classes.textField}
                        value="250"
                        margin="normal"
                        inputProps={{
                          className: classes.amount
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerLeftItem}>
                      <TextField
                        id="standard-name"
                        label="Claim Administrator"
                        className={classes.textField}
                        value="UHOS0011	"
                        margin="normal"
                        readOnly={true}
                        InputProps={{
                          className: classes.readOnly
                        }}
                      />
                    </Grid>
                    <Grid item xs={6} className={classes.innerRightItem}>
                      <TextField
                        id="standard-name"
                        label="Approved"
                        className={classes.textField}
                        value="5000"
                        margin="normal"
                        inputProps={{
                          className: classes.amount
                        }}
                      />
                    </Grid>
                  </Grid>
                </Grid>
              </Grid>
            </Paper>
          </Grid>
          <Grid item xs={12}>
            <Paper className={classes.paper}>
              <Grid container>
                <Grid item xs={12} className={classes.paperHeader}>
                  <Typography variant="h6">Feedback</Typography>
                </Grid>
                <Grid item xs={12}>
                  <Divider />
                </Grid>
                <Grid item xs={12}>
                  <Grid container alignItems="center" justify="center">
                    <Grid item xs={3} />
                    <Grid item xs={6} className={classes.item}>
                      <KeyboardDatePicker
                        margin="normal"
                        id="mui-pickers-date"
                        label="Feedback Date"
                        fullWidth={true}
                        KeyboardButtonProps={{
                          "aria-label": "change date"
                        }}
                      />
                    </Grid>
                    <Grid item xs={3} />
                    <Grid item xs={3} />
                    <Grid item xs={6} className={classes.item}>
                      <FormControl
                        fullWidth={true}
                        className={classes.formInput}
                      >
                        <InputLabel htmlFor="adornment-admin">
                          Enrolment Officer
                        </InputLabel>
                        <Input
                          fullWidth={true}
                          id="adornment-admin"
                          type="text"
                          endAdornment={
                            <InputAdornment position="end">
                              <IconButton>
                                <MoreHoriz />
                              </IconButton>
                            </InputAdornment>
                          }
                        />
                      </FormControl>
                    </Grid>
                    <Grid item xs={3} />
                    <Grid item xs={3} />
                    <Grid item xs={6} className={classes.item}>
                      <FormControlLabel
                        value="start"
                        control={<Switch color="primary" />}
                        label="Care Rendered"
                        labelPlacement="start"
                      />
                    </Grid>
                    <Grid item xs={3} />
                    <Grid item xs={3} />
                    <Grid item xs={6} className={classes.item}>
                      <FormControlLabel
                        value="start"
                        control={<Switch color="primary" />}
                        label="Payment Asked"
                        labelPlacement="start"
                      />
                    </Grid>
                    <Grid item xs={3} />
                    <Grid item xs={3} />
                    <Grid item xs={6} className={classes.item}>
                      <FormControlLabel
                        value="start"
                        control={<Switch color="primary" value={true} />}
                        label="Drugs Prescribed"
                        labelPlacement="start"
                      />
                    </Grid>
                    <Grid item xs={3} />
                    <Grid item xs={3} />
                    <Grid item xs={6} className={classes.item}>
                      <FormControlLabel
                        value="start"
                        control={<Switch color="primary" />}
                        label="Drugs Received"
                        labelPlacement="start"
                        disabled
                      />
                    </Grid>
                    <Grid item xs={3} />
                    <Grid item xs={12} className={classes.item}>
                      <Divider />
                    </Grid>
                    <Grid item xs={3} />
                    <Grid item xs={6} className={classes.item}>
                      <Typography id="discrete-slider-custom" gutterBottom>
                        Overall Assessment
                      </Typography>
                      <Slider
                        max={5}
                        defaultValue={0}
                        getAriaValueText={valuetext}
                        aria-labelledby="discrete-slider-custom"
                        step={1}
                        valueLabelDisplay="auto"
                        marks={marks}
                      />
                    </Grid>
                    <Grid item xs={3} />
                  </Grid>
                </Grid>
              </Grid>
            </Paper>
          </Grid>
        </Grid>
      </form>
      <Fab color="primary" aria-label="Add" className={classes.fab}>
        <SaveAltIcon />
      </Fab>
    </MuiPickersUtilsProvider>
  );
}
